/*
 * xhtmltag.c
 * xhtmlite
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */

#include <gtk/gtk.h>

static gint tag_event_handler (GtkTextTag *tag, GtkWidget *widget, GdkEvent *event,
			       const GtkTextIter *iter, gpointer user_data)
{
	gint char_index;

	char_index = gtk_text_iter_get_offset (iter);
  
	switch (event->type)
	{
		case GDK_MOTION_NOTIFY:
			printf ("Motion event at char %d tag `%s'\n",
				char_index, tag->name);
			break;

		case GDK_BUTTON_PRESS:
			printf ("Button press at char %d tag `%s'\n",
				char_index, tag->name);
			break;

		case GDK_2BUTTON_PRESS:
			printf ("Double click at char %d tag `%s'\n",
				char_index, tag->name);
			break;
 
		case GDK_3BUTTON_PRESS:
			printf ("Triple click at char %d tag `%s'\n",
				char_index, tag->name);
			break;
 
		case GDK_BUTTON_RELEASE:
			printf ("Button release at char %d tag `%s'\n",
				char_index, tag->name);
			break;

		case GDK_KEY_PRESS:
		case GDK_KEY_RELEASE:
	    
			printf ("Key event at char %d tag `%s'\n",
				char_index, tag->name);
			break;
      
		case GDK_ENTER_NOTIFY:
		case GDK_LEAVE_NOTIFY:
		case GDK_PROPERTY_NOTIFY:
		case GDK_SELECTION_CLEAR:
		case GDK_SELECTION_REQUEST:
		case GDK_SELECTION_NOTIFY:
		case GDK_PROXIMITY_IN:
		case GDK_PROXIMITY_OUT:
		case GDK_DRAG_ENTER:
		case GDK_DRAG_LEAVE:
		case GDK_DRAG_MOTION:
		case GDK_DRAG_STATUS:
		case GDK_DROP_START:
		case GDK_DROP_FINISHED:
		default:
			break;
	}

	return FALSE;
}

void xhtmlite_setup_tag (GtkTextTagTable *table, GtkTextTag *tag)
{
	gtk_text_tag_table_add (table, tag);
	g_signal_connect (tag,
			"event",
			G_CALLBACK (tag_event_handler),
			NULL);
}

void xhtmlite_fill_tagtable (GtkTextTagTable *table)
{
	GtkTextTag *tag;

	tag = gtk_text_tag_new   ("u"); //underline
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "underline", PANGO_UNDERLINE_SINGLE,
		      NULL);

	tag = gtk_text_tag_new   ("del"); //strikethrough
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "strikethrough", TRUE,
		      NULL);

	tag = gtk_text_tag_new   ("b"); //bold
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "weight", PANGO_WEIGHT_BOLD,
		      NULL);

	tag = gtk_text_tag_new   ("i"); //italic
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "style", PANGO_STYLE_ITALIC,
		      NULL);

	tag = gtk_text_tag_new   ("sup"); //superscript
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "rise", PANGO_SCALE * 6, //20 for byojeopardy_small, medium and large fonts
		      "size", PANGO_SCALE * 8,
		      NULL);

	tag = gtk_text_tag_new   ("sub"); //subscript
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "rise", PANGO_SCALE * -6,  //-20 for byojeopardy_small, medium and large fonts
		      "size", PANGO_SCALE * 8,
		      NULL);

	tag = gtk_text_tag_new   ("center"); //center
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "justification", GTK_JUSTIFY_CENTER,
		      NULL);

	tag = gtk_text_tag_new   ("right"); //right
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "justification", GTK_JUSTIFY_RIGHT,
		      NULL);

	tag = gtk_text_tag_new   ("left"); //left
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "justification", GTK_JUSTIFY_LEFT,
		      NULL);

	tag = gtk_text_tag_new   ("byojeopardy_small"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 48,
		      NULL);
		      
	tag = gtk_text_tag_new   ("byojeopardy_medium"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 72,
		      NULL);
 
	tag = gtk_text_tag_new   ("byojeopardy_large"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 96,
		      NULL);

	tag = gtk_text_tag_new   ("span font-size='xx-small'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 7,   //1000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "xx-small");

	tag = gtk_text_tag_new   ("span font-size='x-small'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 8,   //20000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "x-small");

	tag = gtk_text_tag_new   ("span font-size='small'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 10,   //40000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "small");
		      
	tag = gtk_text_tag_new   ("span font-size='medium'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 12,   //60000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "medium");
 
	tag = gtk_text_tag_new   ("span font-size='large'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 16,    //80000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "large");

	tag = gtk_text_tag_new   ("span font-size='x-large'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 24,    //100000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "x-large");

	tag = gtk_text_tag_new   ("span font-size='xx-large'"); //byojeopardy_question
	xhtmlite_setup_tag(table,tag);
	g_object_set (tag,
		      "size", PANGO_SCALE * 32,    //120000 for byojeopardy
		      NULL);
	g_object_set_data(G_OBJECT(tag), "font-size_absolute", "xx-large");
}
